diff loadtools/sertool.c @ 50:f1df95eed62c

loadtools: -b option works in fc-iram
author Michael Spacefalcon <msokolov@ivan.Harhan.ORG>
date Sun, 23 Jun 2013 03:32:04 +0000
parents 768a3d012931
children 278052b6afda
line wrap: on
line diff
--- a/loadtools/sertool.c	Sun Jun 23 02:53:16 2013 +0000
+++ b/loadtools/sertool.c	Sun Jun 23 03:32:04 2013 +0000
@@ -1,8 +1,8 @@
 /*
- * This module contains the main() function for fc-sertool: the simplest
- * of the FreeCalypso loading tools, which sends the user-specified
- * IRAM SREC image to the boot ROM and then switches into serial tty
- * pass-through.
+ * This module contains the main() function for fc-iram, previously
+ * called fc-sertool: the simplest of the FreeCalypso loading tools,
+ * which sends the user-specified IRAM SREC image to the boot ROM
+ * and then switches into serial tty pass-through.
  */
 
 #include <sys/types.h>
@@ -22,8 +22,11 @@
 	extern int optind;
 	int c;
 
-	while ((c = getopt(argc, argv, "h:H:i:")) != EOF)
+	while ((c = getopt(argc, argv, "b:h:H:i:")) != EOF)
 		switch (c) {
+		case 'b':
+			set_romload_baudrate(optarg);
+			continue;
 		case 'h':
 			read_hwparam_file_shortname(optarg);
 			continue;
@@ -36,7 +39,7 @@
 		case '?':
 		default:
 usage:			fprintf(stderr,
-			"usage: fc-sertool [options] ttyport iramimage.srec\n");
+			"usage: fc-iram [options] ttyport iramimage.srec\n");
 			exit(1);
 		}
 	if (argc - optind != 2)
@@ -51,7 +54,7 @@
 }
 
 /* called from hwparam.c config file parser */
 /* stub needed for fc-sertool to link */
 void
 set_default_exit_mode()
 {
@@ -51,7 +54,7 @@
 
 /* called from hwparam.c config file parser */
-/* stub needed for fc-sertool to link */
+/* stub needed for fc-iram to link */
 void
 set_default_exit_mode()